@@ -209,8 +209,8 @@ void	destroy_arglist (ArgList *);
  * Specifically, if you create a global variable and then want to delete it,
  * try using a local variable so it is reaped automatically.
  */
-extern	void    add_var_alias      (char *name, char *stuff);
-extern  void    add_local_alias    (char *name, char *stuff);
+extern	void    add_var_alias      (char *name, char *stuff, int noisy);
+extern  void    add_local_alias    (char *name, char *stuff, int noisy);
 extern  void    add_cmd_alias      (char *name, ArgList *arglist, char *stuff);
 extern  void    add_var_stub_alias (char *name, char *stuff);
 extern  void    add_cmd_stub_alias (char *name, char *stuff);
@@ -461,7 +461,7 @@ BUILT_IN_COMMAND(assigncmd)
 	 * Register the variable
 	 */
 	else
-		add_var_alias(real_name, args);
+		add_var_alias(real_name, args, 1);
 
 	new_free(&real_name);
 	return;
@@ -578,7 +578,7 @@ BUILT_IN_COMMAND(localcmd)
 			*next_name++ = 0;
 
 		real_name = remove_brackets(name, NULL, NULL);
-		add_local_alias(real_name, args);
+		add_local_alias(real_name, args, 1);
 		new_free(&real_name);
 		name = next_name;
 	}
@@ -786,7 +786,7 @@ void	prepare_alias_call (void *al, char **stuff)
 		}
 
 		/* Add the local variable */
-		add_local_alias(args->vars[i], next_val);
+		add_local_alias(args->vars[i], next_val, 0);
 		if (expanded)
 			new_free(&expanded);
 	}
@@ -917,7 +917,7 @@ Alias *make_new_Alias (char *name)
  * If ``name'' refers to an already created local variable, that
  * local variable is used (invisibly)
  */
-void	add_var_alias	(char *name, char *stuff)
+void	add_var_alias	(char *name, char *stuff, int noisy)
 {
 	char 	*ptr;
 	Alias 	*tmp = NULL;
@@ -944,13 +944,13 @@ void	add_var_alias	(char *name, char *stuff)
 	 * Weed out FUNCTION_RETURN (die die die)
 	 */
 	else if (!strcmp(name, "FUNCTION_RETURN"))
-		add_local_alias(name, stuff);
+		add_local_alias(name, stuff, noisy);
 
 	/*
 	 * Pass the buck on local variables
 	 */
 	else if ((local == 1) || (local == 0 && find_local_alias(name, NULL)))
-		add_local_alias(name, stuff);
+		add_local_alias(name, stuff, noisy);
 
 	else if (stuff && *stuff)
 	{
@@ -983,16 +983,17 @@ void	add_var_alias	(char *name, char *stuff)
 		/*
 		 * And tell the user.
 		 */
-		say("Assign %s added [%s]", name, stuff);
+		if (noisy)
+			say("Assign %s added [%s]", name, stuff);
 	}
 	else
-		delete_var_alias(name, 1);
+		delete_var_alias(name, noisy);
 
 	new_free(&save);
 	return;
 }
 
-void	add_local_alias	(char *name, char *stuff)
+void	add_local_alias	(char *name, char *stuff, int noisy)
 {
 	char 	*ptr;
 	Alias 	*tmp = NULL;
@@ -1033,9 +1034,9 @@ void	add_local_alias	(char *name, char *stuff)
 	if (tmp->stuff)		/* Oh blah. */
 	{
 		alias_total_bytes_allocated += strlen(tmp->stuff);
-		if (x_debug & DEBUG_LOCAL_VARS)
+		if (x_debug & DEBUG_LOCAL_VARS && noisy)
 		    yell("Assign %s (local) added [%s]", name, stuff);
-		else
+		else if (noisy)
 		    say("Assign %s (local) added [%s]", name, stuff);
 	}
 
@@ -1979,7 +1980,7 @@ static char *	parse_line_alias_special (char *name, char *what, char *args, int
 	if (function)
 	{
 		last_function_call_level = wind_index;
-		add_local_alias("FUNCTION_RETURN", empty_string);
+		add_local_alias("FUNCTION_RETURN", empty_string, 0);
 	}
 	window_display = old_window_display;
 
@@ -2216,16 +2217,16 @@ void 	dump_call_stack 	(void)
 void 	panic_dump_call_stack 	(void)
 {
 	int my_wind_index = wind_index;
-	printf("Call stack\n");
+	fprintf(stderr, "Call stack\n");
 	if (wind_index >= 0)
 	{
 		while (my_wind_index--)
-			printf("[%3d] %s\n", my_wind_index, call_stack[my_wind_index].current);
+			fprintf(stderr, "[%3d] %s\n", my_wind_index, call_stack[my_wind_index].current);
 	}
 	else
-		printf("Stack is corrupted [wind_index is %d], sorry.\n",
+		fprintf(stderr, "Stack is corrupted [wind_index is %d], sorry.\n",
 			wind_index);
-	printf("End of call stack\n");
+	fprintf(stderr, "End of call stack\n");
 }
 
 
@@ -2327,9 +2328,9 @@ char 	*aliasctl 	(char *input)
 		{
 			upper(listc);
 			if (list == VAR_ALIAS_LOCAL)
-				add_local_alias(listc, input);
+				add_local_alias(listc, input, 0);
 			else if (list == VAR_ALIAS)
-				add_var_alias(listc, input);
+				add_var_alias(listc, input, 0);
 			else
 				add_cmd_alias(listc, NULL, input);
 
