@@ -674,7 +674,13 @@ static	time_t	last_ctcp_parsed = 0;
 		/* 
 		 * We did find it.  Acknowledge it.
 		 */
-		ptr = ctcp_cmd[i].func(ctcp_cmd + i, from, to, ctcp_argument);
+		ptr = empty_string;
+		if (do_hook(CTCP_REQUEST_LIST, "%s %s %s %s",
+				from, to, ctcp_command, ctcp_argument))
+		{
+			ptr = ctcp_cmd[i].func(ctcp_cmd + i, from, 
+						to, ctcp_argument);
+		}
 
 		/*
 		 * If this isnt an 'unlimited' CTCP, set up flood protection.
