@@ -551,8 +551,7 @@ static	int		dcc_open (DCC_list *dcc)
 
 			message_from(NULL, LOG_DCC);
 			say("Unable to create connection: [%d] %s", 
-				errno, 
-				errno ? strerror(errno) : "Unknown Host");
+				errno, my_strerror(errno));
 			message_from(NULL, LOG_CURRENT);
 
 			from_server = old_server;
@@ -668,7 +667,7 @@ static	int		dcc_open (DCC_list *dcc)
 			dcc->flags |= DCC_DELETE;
 			message_from(NULL, LOG_DCC);
 			say("Unable to create connection: %s", 
-				errno ? strerror(errno) : "Unknown Host");
+				my_strerror(errno));
 			message_from(NULL, LOG_CURRENT);
 			from_server = old_server;
 			return 0;
@@ -1068,7 +1067,7 @@ static	void 	dcc_close (char *args)
 		return;
 	}
 
-	if (!any_type)
+	if (any_type == 0)	/* User did not specify "-all" type */
 	{
 		for (i = 0; dcc_types[i]; i++)
 			if (!my_stricmp(type, dcc_types[i]))
@@ -1080,15 +1079,15 @@ static	void 	dcc_close (char *args)
 			return;
 		}
 	}
-	else
+	else			/* User did specify "-all" type */
 		i = -1;
 
-	if (any_user)
+	if (any_user)		/* User did specify "-all" user */
 		user = NULL;
 
 	while ((dcc = dcc_searchlist(file, user, i, 0, file, -1)))
 	{
-		unsigned my_type = dcc->flags & DCC_TYPES;
+		unsigned	my_type = dcc->flags & DCC_TYPES;
 
 		count++;
 		dcc->flags |= DCC_DELETE;
@@ -1251,7 +1250,7 @@ static char *	calc_size (off_t fsize)
 /*
  * Usage: /DCC LIST
  */
-void dcc_list (char *args)
+void	dcc_list (char *args)
 {
 	DCC_list	*Client;
 static	char		*format =
@@ -1631,7 +1630,7 @@ char	*dcc_raw_listen (unsigned short port)
 	{
 		Client->flags |= DCC_DELETE; 
 		say("Couldnt establish listening socket: [%d] %s", 
-			Client->read, strerror(errno));
+			Client->read, my_strerror(errno));
 		message_from(NULL, LOG_CURRENT);
 		return m_strdup(empty_string);
 	}
@@ -1810,19 +1809,21 @@ void	register_dcc_offer (char *user, char *type, char *description, char *addres
 	{
 		if (inet_aton(address, &Client->remote) == 0)
 		{
-			say("DCC %s (%s) request from %s had mangled return address [%s]", type, description, user, address);
+			say("DCC %s (%s) request from %s had mangled return "
+				"address [%s]", type, description, 
+						user, address);
 			return;
 		}
 	}
 
 	TempInt = (unsigned)strtoul(port, NULL, 10);
 	Client->remport = htons(TempInt);
-
 	if (TempInt < 1024)
 	{
 		Client->flags |= DCC_DELETE;
-		say("DCC %s (%s) request from %s rejected", 
-			type, description, user);
+		say("DCC %s (%s) request from %s rejected because it "
+			"specified reserved port number (%d) [%s]", 
+				type, description, user, TempInt, port);
 		return;
 	}
 
