@@ -38,13 +38,13 @@
  * input line scrolls to the adjacent zone.  A detailed discussion of zones
  * can be found below.
  */
-const int WIDTH = 10;
+	const int	WIDTH = 10;
 
 /*
  * input_prompt: This is the global default for the raw, unexpanded 
  * input prompt for all input lines, as determined by /set input_prompt.
  */
-static	char	*input_prompt;
+	static	char *	input_prompt;
 
 /* 
  * These are sanity macros.  The file was completely unreadable before 
@@ -498,7 +498,7 @@ void	set_input (char *str)
  * actually change the input buffer.  This is a bad way to change the input
  * buffer tho, cause no bounds checking won't be done 
  */
-char	*get_input (void)
+char *	get_input (void)
 {
 	return &MIN_CHAR;
 }
@@ -511,7 +511,7 @@ void	init_input (void)
 }
 
 /* get_input_prompt: returns the current input_prompt */
-char	*get_input_prompt (void)
+char *	get_input_prompt (void)
 { 
 	return input_prompt;
 }
@@ -1036,12 +1036,12 @@ BUILT_IN_KEYBINDING(backward_character)
 
 BUILT_IN_KEYBINDING(backward_history)
 {
-	get_history(PREV);
+	get_history(OLDER);		/* Cursor up -- older -- prev */
 }
 
 BUILT_IN_KEYBINDING(forward_history)
 {
-	get_history(NEXT);
+	get_history(NEWER);		/* Cursor down -- newer -- next */
 }
 
 BUILT_IN_KEYBINDING(toggle_insert_mode)
@@ -1255,7 +1255,12 @@ void	edit_char (u_char key)
 		int	i;
 
 		if ((i = get_binding(m, key, &func, &ptr)))
-			last_input_screen->meta_hit = i;
+		{
+			if (m == 4 && i == 4)
+				last_input_screen->meta_hit = 0;
+			else
+				last_input_screen->meta_hit = i;
+		}
 		else if (last_input_screen->meta_hit != 4)
 			last_input_screen->meta_hit = 0;
 		if (func)
