@@ -13,14 +13,14 @@
 /*
  * irc_version is what $J returns, its the common-name for the version.
  */
-const char irc_version[] = "EPIC4pre2.507";
-const char useful_info[] = "epic4 pre2 507";
+const char irc_version[] = "EPIC4pre2.511";
+const char useful_info[] = "epic4 pre2 511";
 
 /*
  * internal_version is what $V returns, its the integer-id for the
  * version, and corresponds to the date of release, YYYYMMDD.
  */ 
-const char internal_version[] = "20000327";
+const char internal_version[] = "20000627";
 
 /*
  * As a way to poke fun at the current rage of naming releases after
@@ -28,7 +28,7 @@ const char internal_version[] = "20000327";
  * reality, I have decided to start doing that with EPIC.  These names
  * are intentionally and maliciously silly.  Complaints will be ignored.
  */
-const char ridiculous_version_name[] = "Pusillanimous";
+const char ridiculous_version_name[] = "Scalawag";
 
 #define __need_putchar_x__
 #include "status.h"
@@ -118,6 +118,9 @@ int		trusted_output = 1;
 /* Whether or not we're in CPU saver mode */
 int		cpu_saver = 0;
 
+/* Set to 0 when you want to suppress all beeps (such as window repaints) */
+int		global_beep_ok = 1;
+
 /* The unknown userhost value.  Bogus, but DONT CHANGE THIS!  */
 const char	*unknown_userhost = "<UNKNOWN>@<UNKNOWN>";
 
@@ -319,7 +322,7 @@ SIGNAL_HANDLER(coredump)
 	if (!dead)
 	{
 		term_reset();
-		printf("\
+		fprintf(stderr, "\
 									\n\
 									\n\
 									\n\
@@ -501,9 +504,9 @@ static	void	parse_args (int argc, char **argv)
 		}
 		else
 		{
-			printf("I dont know what your user name is.\n");
-			printf("Set your LOGNAME environment variable\n");
-			printf("and restart IRC II.\n");
+			fprintf(stderr, "I dont know what your user name is.\n");
+			fprintf(stderr, "Set your LOGNAME environment variable\n");
+			fprintf(stderr, "and restart IRC II.\n");
 			exit(1);
 		}
 
@@ -686,16 +689,16 @@ static	void	parse_args (int argc, char **argv)
 	 */
 	if (tmp_hostname)
 	{
-		printf("You specified a hostname of [%s]\n", tmp_hostname);
+		fprintf(stderr, "You specified a hostname of [%s]\n", tmp_hostname);
 		memset(&LocalHostAddr, 0, sizeof(LocalHostAddr));
 		if ((hp = gethostbyname(tmp_hostname)))
 		{
 			memmove((void *)&LocalHostAddr, hp->h_addr, sizeof(LocalHostAddr));
-			printf("Ok.  I'll buy that.\n");
+			fprintf(stderr, "Ok.  I'll buy that.\n");
 			LocalHostName = m_strdup(tmp_hostname);
 		}
 		else
-			printf("I can't configure for that address! (Trying normal hostname...)\n");
+			fprintf(stderr, "I can't configure for that address! (Trying normal hostname...)\n");
 	}
 
 	/*
@@ -705,7 +708,7 @@ static	void	parse_args (int argc, char **argv)
 	{
 		if (gethostname(hostname, NAME_LEN) || strlen(hostname) == 0)
 		{
-			printf("I don't know what your hostname is and I can't do much without it.\n");
+			fprintf(stderr, "I don't know what your hostname is and I can't do much without it.\n");
 			exit(1);
 		}
 	}
@@ -729,7 +732,7 @@ static	void	parse_args (int argc, char **argv)
  * Heavily optimized for EPIC3-final to do as little work as possible
  *			-jfn 3/96
  */
-void io (const char *what)
+void	io (const char *what)
 {
 static	const	char	*caller[51] = { NULL }; /* XXXX */
 	static	int	first_time = 1,
@@ -1155,16 +1158,16 @@ int 	main (int argc, char *argv[])
 	parse_args(argc, argv);
 	init_keys();
 
-	printf("EPIC Version 4 -- %s\n", ridiculous_version_name);
-	printf("EPIC Software Labs (2000)\n");
-	printf("Version (%s) -- Date (%s)\n", irc_version, internal_version);
-	printf("%s\n", compile_info);
-	printf("Process [%d]", getpid());
+	fprintf(stderr, "EPIC Version 4 -- %s\n", ridiculous_version_name);
+	fprintf(stderr, "EPIC Software Labs (2000)\n");
+	fprintf(stderr, "Version (%s) -- Date (%s)\n", irc_version, internal_version);
+	fprintf(stderr, "%s\n", compile_info);
+	fprintf(stderr, "Process [%d]", getpid());
 	if (isatty(0))
-		printf(" connected to tty [%s]", ttyname(0));
+		fprintf(stderr, " connected to tty [%s]", ttyname(0));
 	else
 		dumb_mode = 1;
-	printf("\n");
+	fprintf(stderr, "\n");
 
 	FD_ZERO(&readables);
 	FD_ZERO(&writables);
