@@ -51,6 +51,8 @@ typedef struct _mo_money
 
 static int	malloc_check (void *ptr)
 {
+	if (!ptr)
+		return ALLOC_MAGIC_FAILED;
 	if (magic(ptr) != ALLOC_MAGIC)
 		return ALLOC_MAGIC_FAILED;
 	if (alloc_size(ptr) == FREED_VAL)
@@ -64,15 +66,26 @@ void	fatal_malloc_check (void *ptr, const char *special, char *fn, int line)
 	{
 	    case ALLOC_MAGIC_FAILED:
 	    {
-		yell("Magic check failed");
+		yell("IMPORTANT! MAKE SURE TO INCLUDE ALL OF THIS INFORMATION" 
+			" IN YOUR BUG REPORT!");
+		yell("MAGIC CHECK OF MALLOCED MEMORY FAILED!");
 		if (special)
 			yell("Because of: [%s]", special);
 
-		yell("MAKE SURE TO INCLUDE THIS INFORMATION IN THE BUG REPORT!");
-		yell("Address: [%p]  Size: [%d]  Magic: [%x] (should be [%lx])",
-			ptr, alloc_size(ptr), magic(ptr), ALLOC_MAGIC);
-		yell("Dump: [%s]", prntdump(ptr, alloc_size(ptr)));
-		panic("new_free()'s magic check failed from [%s/%d].", 
+		if (ptr)
+		{
+			yell("Address: [%p]  Size: [%d]  Magic: [%x] "
+				"(should be [%lx])",
+				ptr, alloc_size(ptr), magic(ptr), ALLOC_MAGIC);
+			yell("Dump: [%s]", prntdump(ptr, alloc_size(ptr)));
+		}
+		else
+			yell("Address: [NULL]");
+
+		yell("IMPORTANT! MAKE SURE TO INCLUDE ALL OF THIS INFORMATION" 
+			" IN YOUR BUG REPORT!");
+		panic("BE SURE TO INCLUDE THE ABOVE IMPORTANT INFORMATION! "
+			"-- new_free()'s magic check failed from [%s/%d].", 
 			fn, line);
 	    }
 
@@ -448,38 +461,6 @@ char *	rstristr (const char *source, const char *search)
 }
 
 
-/* 
- * word_count:  Efficient way to find out how many words are in
- * a given string.  Relies on my_isspace() not being broken.
- */
-int     word_count (char *str)
-{
-        int cocs = 0;
-        int isv = 1;
-        char *foo = str;
-
-        if (!foo)
-                return 0;
-
-        while (*foo)
-        {
-		if (*foo == '"' && isv)
-		{
-			while (foo[1] && *++foo != '"')
-				;
-			isv = 0;
-			cocs++;
-		}
-                if (!my_isspace(*foo) != !isv)
-                {
-                        isv = my_isspace(*foo);
-                        cocs++;
-                }
-                foo++;
-        }
-        return (cocs + 1) / 2;
-}
-
 char *	next_arg (char *str, char **new_ptr)
 {
 	char	*ptr;
@@ -1191,6 +1172,40 @@ int	is_number (const char *str)
 		return 0;
 }
 
+/* is_number: returns 1 if the given string is a real number, 0 otherwise */
+int	is_real_number (const char *str)
+{
+	int	dot = 0;
+
+	if (!str || !*str)
+		return 0;
+
+	while (*str == ' ')
+		str++;
+
+	if (*str == '-')
+		str++;
+
+	if (!*str)
+		return 0;
+
+	for (; *str; str++)
+	{
+		if (isdigit((*str)))
+			continue;
+
+		if (*str == '.' && dot == 0)
+		{
+			dot = 1;
+			continue;
+		}
+
+		return 0;
+	}
+
+	return 1;
+}
+
 /*
  * path_search: given a file called name, this will search each element of
  * the given path to locate the file.  If found in an element of path, the
@@ -1289,9 +1304,9 @@ static	int recursion = 0;		/* Recursion is bad */
 	}
 
 	term_reset();
-	printf("An unrecoverable logic error has occured.\n");
-	printf("Please fill out the BUG_FORM file, and include the following message:\n");
-	printf("Panic: [%s:%s]\n", irc_version, buffer);
+	fprintf(stderr, "An unrecoverable logic error has occured.\n");
+	fprintf(stderr, "Please fill out the BUG_FORM file, and include the following message:\n");
+	fprintf(stderr, "Panic: [%s:%s]\n", irc_version, buffer);
 	panic_dump_call_stack();
 
 	if (x_debug & DEBUG_CRASH)
@@ -1967,6 +1982,9 @@ char *	unsplitw (char ***container, int howmany)
 	char *retval = NULL;
 	char **str = *container;
 
+	if (!str || !*str)
+		return NULL;
+
 	while (howmany)
 	{
 		m_s3cat(&retval, " ", *str);
@@ -2535,6 +2553,9 @@ static 	char 	*mystuff = NULL;
 		else
 			*host = firstback;
 
+		if (!*host)
+			return -1;		/* Invalid hostname */
+
 		**host = 0;
 		(*host)++;
 	}
@@ -3097,3 +3118,273 @@ char *	urldecode (char *s)
 	return strcpy(s, retval);
 }
 
+unsigned char isspace_table [256] = 
+{
+	0,	0,	0,	0,	0,	0,	0,	0,
+	0,	1,	1,	1,	1,	1,	0,	0,
+	0,	0,	0,	0,	0,	0,	0,	0,
+	0,	0,	0,	0,	0,	0,	0,	0,
+	1,	0,	0,	0,	0,	0,	0,	0,
+	0,	0,	0,	0,	0,	0,	0,	0,
+	0,	0,	0,	0,	0,	0,	0,	0,
+	0,	0,	0,	0,	0,	0,	0,	0,
+	0,	0,	0,	0,	0,	0,	0,	0,
+	0,	0,	0,	0,	0,	0,	0,	0,
+	0,	0,	0,	0,	0,	0,	0,	0,
+	0,	0,	0,	0,	0,	0,	0,	0,
+	0,	0,	0,	0,	0,	0,	0,	0,
+	0,	0,	0,	0,	0,	0,	0,	0,
+	0,	0,	0,	0,	0,	0,	0,	0,
+	0,	0,	0,	0,	0,	0,	0,	0,
+
+	0,	0,	0,	0,	0,	0,	0,	0,
+	0,	0,	0,	0,	0,	0,	0,	0,
+	0,	0,	0,	0,	0,	0,	0,	0,
+	0,	0,	0,	0,	0,	0,	0,	0,
+	0,	0,	0,	0,	0,	0,	0,	0,
+	0,	0,	0,	0,	0,	0,	0,	0,
+	0,	0,	0,	0,	0,	0,	0,	0,
+	0,	0,	0,	0,	0,	0,	0,	0,
+	0,	0,	0,	0,	0,	0,	0,	0,
+	0,	0,	0,	0,	0,	0,	0,	0,
+	0,	0,	0,	0,	0,	0,	0,	0,
+	0,	0,	0,	0,	0,	0,	0,	0,
+	0,	0,	0,	0,	0,	0,	0,	0,
+	0,	0,	0,	0,	0,	0,	0,	0,
+	0,	0,	0,	0,	0,	0,	0,	0,
+	0,	0,	0,	0,	0,	0,	0,	0,
+};
+
+#if 0
+/* 
+ * word_count:  Efficient way to find out how many words are in
+ * a given string.  Relies on my_isspace() not being broken.
+ */
+int     word_count (const char *str)
+{
+	const char *	p;
+	int		count = 0;
+
+        if (!str || !*str)
+                return 0;
+
+	if (*str == '"')
+	{
+		while (*str && *++str != '"')
+			str++;
+		if (!*str)
+			return 1;
+		str++;
+	}
+	else while (my_isspace(*str))
+		str++;
+
+	for (count = 1, p = str; *p; p++)
+        {
+		if ((my_isspace(*p) && p[1] == '"'))
+		{
+			if (*p != '"')
+				p++;
+			while (p[1] && *++p != '"')
+				;
+			count++;
+			continue;
+		}
+
+		if (my_isspace(*p) && !isspace(p[1]))
+			count++;
+	}
+
+	return count;
+}
+#else
+
+/* 
+ * XXX XXX XXX -- This is expensive, and ugly, but it counts words
+ * in the same way as new_next_word, and that is all that counts for now.
+ */
+int	word_count (const char *ptr)
+{
+	int	count = 0;
+
+	if (!ptr || !*ptr)
+		return 0;
+
+	/* Skip any leading whitespace */
+	while (*ptr && risspace(*ptr))
+		ptr++;
+
+	while (ptr && *ptr)
+	{
+		/* Always pre-count words */
+		count++;
+
+		/* 
+		 * If this is an extended word, then skip everything
+		 * up to the first un-backslashed double quote.
+		 */
+		if (*ptr == '"')
+		{
+			for (ptr++; *ptr; ptr++)
+			{
+				if (*ptr == '\\' && ptr[1])
+					ptr++;
+				else if (*ptr == '"')
+				{
+					ptr++;
+					break;
+				}
+			}
+		}
+
+		/* 
+		 * This is a regular word, skip all of the non-whitespace
+		 * characters.
+		 */
+		else
+		{
+			while (*ptr && !risspace(*ptr))
+				ptr++;
+		}
+
+		/* Skip any leading whitespace before the next word */
+		while (*ptr && risspace(*ptr))
+			ptr++;
+	}
+
+	return count;
+}
+#endif
+
+/*
+ * A "forward quote" is the first double quote we find that has a space
+ * or the end of string after it; or the end of the string.
+ */
+const char *	find_forward_quote (const char *input, const char *start)
+{
+	/*
+	 * An "extended word" is defined as:
+	 *	<SPACE> <QUOTE> <ANY>* <QUOTE> <SPACE>
+	 * <SPACE> := <WORD START> | <WORD END> | <" "> | <"\t"> | <"\n">
+	 * <QUOTE> :- <'"'>
+	 * <ANY>   := ANY ASCII CHAR 0 .. 256
+	 */
+	/* Make sure we are actually looking at a double-quote */
+	if (*input != '"')
+		return NULL;
+
+	/* 
+	 * Make sure that the character before is the start of the
+	 * string or that it is a space.
+	 */
+	if (input > start && !risspace(input[-1]))
+		return NULL;
+
+	/*
+	 * Walk the string looking for a double quote.  Yes, we do 
+	 * really have to check for \'s, still, because the following
+	 * still is one word:
+	 *			"one\" two"
+	 * Once we find a double quote, then it must be followed by 
+	 * either the end of string (chr 0) or a space.  If we find 
+	 * that, return the position of the double-quote.  
+	 */
+	for (input++; *input; input++)
+	{
+		if (input[0] == '\\' && input[1])
+			input++;
+		else if (input[0] == '"')
+		{
+			if (input[1] == 0)
+				return input;
+			else if (risspace(input[1]))
+				return input;
+		}
+	}
+
+	/*
+	 * If we get all the way to the end of the string w/o finding 
+	 * a matching double-quote, return the position of the (chr 0), 
+	 * which is a special meaning to the caller. 
+	 */
+	return input;		/* Bumped the end of string. doh! */
+}
+
+/*
+ * A "backward quote" is the first double quote we find, going backward,
+ * that has a space or the start of string after it; or the start of 
+ * the string.
+ */
+const char *	find_backward_quote (const char *input, const char *start)
+{
+	const char *	saved_input = input;
+
+	/*
+	 * An "extended word" is defined as:
+	 *	<SPACE> <QUOTE> <ANY>* <QUOTE> <SPACE>
+	 * <SPACE> := <WORD START> | <WORD END> | <" "> | <"\t"> | <"\n">
+	 * <QUOTE> :- <'"'>
+	 * <ANY>   := ANY ASCII CHAR 0 .. 256
+	 */
+	/* Make sure we are actually looking at a double-quote */
+	if (input[0] != '"')
+		return NULL;
+
+	/* 
+	 * Make sure that the character after is either the end of the
+	 * string, or that it is a space.
+	 */
+	if (input[1] && !risspace(input[1]))
+		return NULL;
+
+	/*
+	 * Walk the string looking for a double quote.  Yes, we do 
+	 * really have to check for \'s, still, because the following
+	 * still is one word:
+	 *			"one\" two"
+	 * Once we find a double quote, then it must be followed by 
+	 * either the end of string (chr 0) or a space.  If we find 
+	 * that, return the position of the double-quote.  
+	 */
+	for (input--; input > start; input--)
+	{
+		if (input[0] == '\\' && input[1])
+			input++;
+		else if (input[0] == '"')
+		{
+			if (input[1] == 0)
+				return input;
+			else if (risspace(input[1]))
+				return input;
+		}
+	}
+
+	/*
+	 * If we get all the way to the start of the string w/o finding 
+	 * a matching double-quote, then THIS IS NOT AN EXTENDED WORD!
+	 * We need to re-do this word entirely by starting over and looking
+	 * for a normal word.
+	 */
+	input = saved_input;
+	while (input > start && !risspace(input[0]))
+		input--;
+
+	if (risspace(input[0]))
+		input++;		/* Just in case we've gone too far */
+
+	return input;		/* Wherever we are is fine. */
+}
+
+const char *	my_strerror (int number)
+{
+	if (number < 0)
+	{
+#ifdef HAVE_HSTRERROR
+		return hstrerror(h_errno);
+#else
+		return "Hostname lookup failure";
+#endif
+	}
+	return strerror(errno);
+}
+
