@@ -371,9 +371,9 @@ void 	add_to_window (Window *window, const unsigned char *str)
 		display_bold(OFF);
 
 		if (window->screen)
-			cols = window->screen->co;
+			cols = window->screen->co - 1;	/* XXX HERE XXX */
 		else
-			cols = window->columns;
+			cols = window->columns - 1;
 
 		/* Suppress status updates while we're outputting. */
 		for (lines = split_up_line(str, cols); *lines; lines++)
@@ -702,12 +702,25 @@ const 	u_char	*ptr;
 		 * want to treat this exactly as 1 line, and col has already 
 		 * been incremented.
 		 */
-#if 0
-		if (col >= max_cols || newline)
-#else
-		if (((col > max_cols) && ptr[1]) || newline)
-#endif
+		if ((col > max_cols) || newline)
 		{
+			/*
+			 * We just incremented col, but we need to decrement
+			 * it in order to keep the count correct!
+			 *		--zinx
+			 */
+			if (col > max_cols)
+				col--;
+
+			/*
+			 * XXX Hackwork and trickery here.  In the very rare
+			 * case where we end the output string *exactly * at
+			 * the end of the line, then do not do any more of
+			 * the following handling.  Just punt right here.
+			 */
+			if (ptr[1] == 0)
+				break;		/* stop all processing */
+
 			/*
 			 * Default the end of line wrap to the last character
 			 * we parsed if there were no spaces in the line, or
@@ -819,7 +832,9 @@ const 	u_char	*ptr;
 			strlcpy(buffer, cont, BIG_BUFFER_SIZE / 2);
 			strlcat(buffer, pos_copy, BIG_BUFFER_SIZE / 2);
 
-			col = pos = strlen(buffer);
+			pos = strlen(buffer);
+			/* Watch this -- ugh. how expensive! :( */
+			col = output_with_count(buffer, 0, 0);
 			word_break = 0;
 			newline = 0;
 
@@ -1122,7 +1137,7 @@ static	int	altc = OFF;
 /*
  * A temporary wrapper function for backwards compatibility.
  */
-int	output_line(const unsigned char *str)
+int	output_line (const unsigned char *str)
 {
 	output_with_count(str,1, 1);
 	return 0;
@@ -1644,6 +1659,7 @@ void 	repaint_window (Window *w, int start_line, int end_line)
 	for (count = 0; count < start_line; count++)
 		curr_line = curr_line->next;
 
+	global_beep_ok = 0;		/* Suppress beeps */
 	window->cursor = start_line;
 	for (count = start_line; count < end_line; count++)
 	{
@@ -1654,6 +1670,7 @@ void 	repaint_window (Window *w, int start_line, int end_line)
 
 		curr_line = curr_line->next;
 	}
+	global_beep_ok = 1;		/* Suppress beeps */
 
 	/*
 	 * If "end_line" is -1, then we're supposed to clear off the rest
@@ -1666,9 +1683,6 @@ void 	repaint_window (Window *w, int start_line, int end_line)
 			term_clear_to_eol();
 			term_newline();
 		}
-#if 0		/* XXXX - This, i believe, is bogus */
-		update_window_status(window, 1);
-#endif
 	}
 
 	recalculate_window_cursor(window);	/* XXXX */
@@ -1813,8 +1827,9 @@ Window	*create_additional_screen (void)
 	s = connect_by_number(NULL, &port, SERVICE_SERVER, PROTOCOL_TCP);
 	if (s < 0)
 	{
-		yell("Couldnt establish server side -- error [%d]", s);
-		return (Window *) 0;
+		yell("Couldnt establish server side -- error [%d] [%s]", 
+				s, my_strerror(errno));
+		return NULL;
 	}
 
 	oldscreen = current_window->screen;
@@ -2618,7 +2633,9 @@ unsigned char *strip_ansi (const unsigned char *str)
 			case ('*') : case ('+') : case ('$') :
 			case ('@') :
 			{
-				next_char();	/* Skip the argument */
+				chr = next_char();
+				if (chr == 0)
+					put_back();	/* Bogus sequence */
 				break;
 			}
 
